@@ -3,29 +3,33 @@ macro_rules! help_msg {
         concat!(
             version_msg!(),
             "\n",
-            "Usage:\n",
-            "  aki-xcat [options] [<file>...]\n",
-            "\n",
-            "this is like a cat, zcat, xzcat, zstdcat and lz4cat.\n",
-            "with no <file> or when <file> is -, read standard input.\n",
-            "automatic discovery file type: plain, gz, xz, zst and lz4.\n",
-            "\n",
-            "Options:\n",
-            "  -n, --number          output line number for each lines\n",
-            "  -f, --file-name       output file name for each lines\n",
-            "      --path-name       output path name for each lines\n",
-            "  -p, --pipe-in <num>   read from pipe <num> [unimplemented]\n",
-            "\n",
-            "  -H, --help        display this help and exit\n",
-            "  -V, --version     display version information and exit\n",
-            "  -X <x-options>    x options. try -X help\n",
-            "\n",
-            "Argument:\n",
-            "  <file>         utf-8 encoded text file. A compressed file of it by gzip, xz, zstd, lz4.\n",
-            "\n",
-            "Examples:\n",
-            "  You can simple use. Just arrange the files.\n",
-            "    aki-xcat file1 file2.gz file3.xz file4.zst file5.lz4\n",
+            indoc::indoc!(
+                r#"
+            Usage:
+              aki-xcat [options] [<file>...]
+
+            this is like a cat, zcat, xzcat, zstdcat and lz4cat.
+            with no <file> or when <file> is -, read standard input.
+            automatic discovery file type: plain, gz, xz, zst and lz4.
+
+            Options:
+              -n, --number          output line number for each lines
+              -f, --file-name       output file name for each lines
+                  --path-name       output path name for each lines
+              -p, --pipe-in <num>   read from pipe <num> [unimplemented]
+
+              -H, --help        display this help and exit
+              -V, --version     display version information and exit
+              -X <x-options>    x options. try -X help
+
+            Argument:
+              <file>         utf-8 encoded text file. A compressed file of it by gzip, xz, zstd, lz4.
+
+            Examples:
+              You can simple use. Just arrange the files.
+                aki-xcat file1 file2.gz file3.xz file4.zst file5.lz4
+            "#
+            ),
             "\n"
         )
     };
